summaryrefslogtreecommitdiffstats
path: root/juk/filerenamer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
commite654398e46e37abf457b2b1122ab898d2c51c49f (patch)
treed39ee6440f3c3663c3ead84a2d4cc2d034667e96 /juk/filerenamer.h
parente4f29b18e19394b9352f52a6c0d0d0e3932cf511 (diff)
downloadtdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.tar.gz
tdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1157644 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'juk/filerenamer.h')
-rw-r--r--juk/filerenamer.h80
1 files changed, 40 insertions, 40 deletions
diff --git a/juk/filerenamer.h b/juk/filerenamer.h
index 0097ed86..66548039 100644
--- a/juk/filerenamer.h
+++ b/juk/filerenamer.h
@@ -17,9 +17,9 @@
#ifndef JUK_FILERENAMER_H
#define JUK_FILERENAMER_H
-#include <qstring.h>
-#include <qvaluevector.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqvaluevector.h>
+#include <tqmap.h>
#include "filerenamerbase.h"
#include "filerenameroptions.h"
@@ -41,21 +41,21 @@ enum MovementDirection { MoveUp, MoveDown };
/**
* This is used by FileRenamerWidget to store information about a particular
- * tag type, including its position, the QFrame holding the information,
+ * tag type, including its position, the TQFrame holding the information,
* the up, down, and enable buttons, and the user-selected renaming options.
*/
struct Row
{
Row() : widget(0), upButton(0), downButton(0), enableButton(0) {}
- QWidget *widget;
+ TQWidget *widget;
- QPushButton *upButton, *downButton, *optionsButton, *enableButton;
+ TQPushButton *upButton, *downButton, *optionsButton, *enableButton;
TagRenamerOptions options;
CategoryID category; // Includes category and a disambiguation id.
unsigned position; ///< Position in the GUI (0 == top)
- QString name;
+ TQString name;
};
/**
@@ -65,7 +65,7 @@ struct Row
* takes up. The index into the vector is known as the row identifier (which is unique but
* not necessarily constant).
*/
-typedef QValueVector<Row> Rows;
+typedef TQValueVector<Row> Rows;
/**
* Holds a list directory separator checkboxes which separate a row. There
@@ -73,14 +73,14 @@ typedef QValueVector<Row> Rows;
*
* Used for ConfigCategoryReader.
*/
-typedef QValueVector<QCheckBox *> DirSeparatorCheckBoxes;
+typedef TQValueVector<TQCheckBox *> DirSeparatorCheckBoxes;
/**
* Associates a CategoryID combination with a set of options.
*
* Used for ConfigCategoryReader
*/
-typedef QMap<CategoryID, TagRenamerOptions> CategoryOptionsMap;
+typedef TQMap<CategoryID, TagRenamerOptions> CategoryOptionsMap;
/**
* An implementation of CategoryReaderInterface that reads the user's settings
@@ -102,14 +102,14 @@ public:
// CategoryReaderInterface reimplementations
- virtual QString categoryValue(TagType type) const;
- virtual QString prefix(const CategoryID &category) const;
- virtual QString suffix(const CategoryID &category) const;
+ virtual TQString categoryValue(TagType type) const;
+ virtual TQString prefix(const CategoryID &category) const;
+ virtual TQString suffix(const CategoryID &category) const;
virtual TagRenamerOptions::EmptyActions emptyAction(const CategoryID &category) const;
- virtual QString emptyText(const CategoryID &category) const;
- virtual QValueList<CategoryID> categoryOrder() const;
- virtual QString separator() const;
- virtual QString musicFolder() const;
+ virtual TQString emptyText(const CategoryID &category) const;
+ virtual TQValueList<CategoryID> categoryOrder() const;
+ virtual TQString separator() const;
+ virtual TQString musicFolder() const;
virtual int trackWidth(unsigned categoryNum) const;
virtual bool hasFolderSeparator(unsigned index) const;
virtual bool isDisabled(const CategoryID &category) const;
@@ -117,10 +117,10 @@ public:
private:
const PlaylistItem *m_currentItem;
CategoryOptionsMap m_options;
- QValueList<CategoryID> m_categoryOrder;
- QString m_separator;
- QString m_musicFolder;
- QValueVector<bool> m_folderSeparators;
+ TQValueList<CategoryID> m_categoryOrder;
+ TQString m_separator;
+ TQString m_musicFolder;
+ TQValueVector<bool> m_folderSeparators;
};
/**
@@ -142,7 +142,7 @@ class FileRenamerWidget : public FileRenamerBase, public CategoryReaderInterface
Q_OBJECT
public:
- FileRenamerWidget(QWidget *parent);
+ FileRenamerWidget(TQWidget *parent);
~FileRenamerWidget();
/// Maximum number of total categories the widget will allow.
@@ -232,7 +232,7 @@ private:
* @param category the category to retrieve the value for.
* @return the string representation of the value for \p category.
*/
- QString fileCategoryValue(TagType category) const;
+ TQString fileCategoryValue(TagType category) const;
/**
* Returns the value for \p category by reading the user entry for that
@@ -242,7 +242,7 @@ private:
* @param category the category to retrieve the value for.
* @return the string representation of the value for \p category.
*/
- virtual QString categoryValue(TagType category) const;
+ virtual TQString categoryValue(TagType category) const;
/**
* Returns the user-specified prefix string for \p category.
@@ -250,7 +250,7 @@ private:
* @param category the category to retrieve the value for.
* @return user-specified prefix string for \p category.
*/
- virtual QString prefix(const CategoryID &category) const
+ virtual TQString prefix(const CategoryID &category) const
{
return m_rows[findIdentifier(category)].options.prefix();
}
@@ -261,7 +261,7 @@ private:
* @param category the category to retrieve the value for.
* @return user-specified suffix string for \p category.
*/
- virtual QString suffix(const CategoryID &category) const
+ virtual TQString suffix(const CategoryID &category) const
{
return m_rows[findIdentifier(category)].options.suffix();
}
@@ -284,7 +284,7 @@ private:
* @param category the category to retrieve the value for.
* @return the user-specified empty text for \p category.
*/
- virtual QString emptyText(const CategoryID &category) const
+ virtual TQString emptyText(const CategoryID &category) const
{
return m_rows[findIdentifier(category)].options.emptyText();
}
@@ -292,17 +292,17 @@ private:
/**
* @return list of CategoryIDs corresponding to the user-specified category order.
*/
- virtual QValueList<CategoryID> categoryOrder() const;
+ virtual TQValueList<CategoryID> categoryOrder() const;
/**
* @return string that separates the tag values in the file name.
*/
- virtual QString separator() const;
+ virtual TQString separator() const;
/**
* @return local path to the music folder used to store renamed files.
*/
- virtual QString musicFolder() const;
+ virtual TQString musicFolder() const;
/**
* @param categoryNum Zero-based number of category to get results for (if more than one).
@@ -399,7 +399,7 @@ private slots:
*
* @param file the path to the local file to read.
*/
- virtual void fileSelected(const QString &file);
+ virtual void fileSelected(const TQString &file);
/**
* This function reads the tags from the user-supplied examples and ensures
@@ -419,7 +419,7 @@ private slots:
/**
* This function removes the row identified by id and updates the internal data to be
* consistent again, by forwarding the call to removeRow().
* This roundabout way is done due to QSignalMapper.
*
* @param id The unique id to update
*/
@@ -451,7 +451,7 @@ private slots:
private:
/// This is the frame that holds all of the category widgets and checkboxes.
- QVBox *m_mainFrame;
+ TQVBox *m_mainFrame;
/**
* This is the meat of the widget, it holds the rows for the user configuration. It is
@@ -475,13 +475,13 @@ private:
/// This is true if we're reading example tags from m_exampleFile.
bool m_exampleFromFile;
- QString m_exampleFile;
+ TQString m_exampleFile;
// Used to map signals from rows to the correct widget.
- QSignalMapper *mapper;
- QSignalMapper *toggleMapper;
- QSignalMapper *upMapper;
- QSignalMapper *downMapper;
+ TQSignalMapper *mapper;
+ TQSignalMapper *toggleMapper;
+ TQSignalMapper *upMapper;
+ TQSignalMapper *downMapper;
};
/**
@@ -521,7 +521,7 @@ public:
*
* @param interface object to read options/data from.
*/
- static QString fileName(const CategoryReaderInterface &interface);
+ static TQString fileName(const CategoryReaderInterface &interface);
private:
/**
@@ -535,7 +535,7 @@ private:
* Attempts to rename the file from \a src to \a dest. Returns true if the
* operation succeeded.
*/
- bool moveFile(const QString &src, const QString &dest);
+ bool moveFile(const TQString &src, const TQString &dest);
};
#endif /* JUK_FILERENAMER_H */
@@ -419,7 +419,7 @@ private slots:
* This function removes the row identified by id and updates the internal data to be
* consistent again, by forwarding the call to removeRow().
- * This roundabout way is done due to QSignalMapper.
+ * This roundabout way is done due to TQSignalMapper.
*
* @param id The unique id to update